==> ocg_login-0.0.1.tar.gz: lib/src/repository/login.dart <==
import 'dart:convert';

import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:ocg_login/src/repository/token.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:http/http.dart' as http;
import 'package:uuid/uuid.dart';
import '../database/login.dart';

abstract class LoginRepository {
  Future<AppResponse<bool>> loginUser(User user);
  Future<AppResponse<bool>> isLoggedIn();
}

class LoginTestRepository extends LoginRepository {
  final LoginDatabase loginDatabase;
  final UserRepository userRepository;

  LoginTestRepository(
    this.loginDatabase,
    this.userRepository,
  );

  @override
  Future<AppResponse<bool>> loginUser(User user) async {
    try {
      if (!loginDatabase.isOpened) {
        await loginDatabase.open();
      }
      AppResponse<User> userResponsne = await userRepository.createUser(user);
      if (userResponsne.isSuccess) {
        User data = userResponsne.data;
        AppResponse<bool> response = await loginDatabase.storeUser(data.id);

        return response;
      }
      return AppResponse.named(error: "Login failed");
    } catch (e) {
      debugPrint("Login $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> isLoggedIn() async {
    try {
      AppResponse<AppToken> response = await loginDatabase.getToken();
      debugPrint("Token ${response.data}");
      return AppResponse.named(data: response.isSuccess);
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }
}

class LoginNetworkRepository extends LoginRepository {
  final LoginTokenRepository tokenRepository;
  final http.BaseClient client;

  LoginNetworkRepository(this.tokenRepository, this.client);

  @override
  Future<AppResponse<bool>> loginUser(User user) async {
    try {
      String url = "${ApiConfig.BASE_URL}/tmp/user/";
      var json = {
        "id": Uuid().v4().substring(0, 24),
        "name": "${user.name}",
        "status": "${user.status}",
        "profilePic": "${user.profilePic}"
      };
      var response = await client.post(url,
          body: jsonEncode(json), headers: ApiConfig.headers);
      var responseJson = jsonDecode(response.body);
      if (responseJson["token"] != null) {
        return await tokenRepository.saveToken(AppToken.named(
            token: responseJson["token"], userId: responseJson["user_id"]));
      }
      return AppResponse.named(data: false);
    } catch (e) {
      debugPrint("Error ${e.toString()}");
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  @override
  Future<AppResponse<bool>> isLoggedIn() async {
    try {
      AppResponse<AppToken> response = await tokenRepository.getToken();
      return AppResponse.named(data: response.isSuccess);
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }
}

==> ocg_login-0.0.3.tar.gz: lib/src/repository/login.dart <==
import 'dart:convert';

import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:ocg_login/src/repository/token.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:http/http.dart' as http;
import 'package:uuid/uuid.dart';
import '../database/login.dart';

abstract class LoginRepository {
  Future<AppResponse<bool>> loginUser(User user);
  Future<AppResponse<bool>> isLoggedIn();
}

class LoginTestRepository extends LoginRepository {
  final LoginDatabase loginDatabase;

  LoginTestRepository(
    this.loginDatabase,
  );

  @override
  Future<AppResponse<bool>> loginUser(User user) async {
    try {
      if (!loginDatabase.isOpened) {
        await loginDatabase.open();
      }
      // AppResponse<User> userResponsne = await userRepository.createUser(user);
      // if (userResponsne.isSuccess) {
      //   User data = userResponsne.data;
      //   AppResponse<bool> response = await loginDatabase.storeUser(data.id);

      //   return response;
      // }
      return AppResponse.named(error: "Login failed");
    } catch (e) {
      debugPrint("Login $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> isLoggedIn() async {
    try {
      AppResponse<AppToken> response = await loginDatabase.getToken();
      debugPrint("Token ${response.data}");
      return AppResponse.named(data: response.isSuccess);
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }
}

class LoginNetworkRepository extends LoginRepository {
  final LoginTokenRepository tokenRepository;
  final http.BaseClient client;

  LoginNetworkRepository(this.tokenRepository, this.client);

  @override
  Future<AppResponse<bool>> loginUser(User user) async {
    try {
      String url = "tmp/user/";
      var json = {
        "id": Uuid().v4().substring(0, 24),
        "name": "${user.name}",
        "status": "${user.status}",
        "profilePic": "${user.profilePic}"
      };
      var response = await client.post(url,
          body: jsonEncode(json), headers: ApiConfig.headers);
      var responseJson = jsonDecode(response.body);
      if (responseJson["token"] != null) {
        return await tokenRepository.saveToken(AppToken.named(
            token: responseJson["token"], userId: responseJson["user_id"]));
      }
      return AppResponse.named(data: false);
    } catch (e) {
      debugPrint("Error ${e.toString()}");
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  @override
  Future<AppResponse<bool>> isLoggedIn() async {
    try {
      AppResponse<AppToken> response = await tokenRepository.getToken();
      return AppResponse.named(data: response.isSuccess);
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }
}
